abacusai.api_client_utils — AbacusAI documentation

# `abacusai.api_client_utils`

## Module Contents

### Functions

`clean_column_name`(column) |
`get_clean_function_source_code`(func) |
`avro_to_pandas_dtype`(avro_type) |
`get_non_nullable_type`(types) |
`get_object_from_context`(client, context, ...) |

### Attributes

`INVALID_PANDAS_COLUMN_NAME_CHARACTERS` |

abacusai.api_client_utils.INVALID_PANDAS_COLUMN_NAME_CHARACTERS = '[^A-Za-z0-9_]'

abacusai.api_client_utils.clean_column_name(column)

abacusai.api_client_utils.get_clean_function_source_code(func)
  Parameters:

    func (Callable) –

abacusai.api_client_utils.avro_to_pandas_dtype(avro_type)

abacusai.api_client_utils.get_non_nullable_type(types)

abacusai.api_client_utils.get_object_from_context(client, context, variable_name, return_type)